from setuptools import setup

setup(name='distributions_Guassian_Binomial',
      version='0.2',
      description='Gaussian distributions',
      packages=['distributions_Guassian_Binomial'],
      zip_safe=False)
